# *-* coding:utf-8 *-*
"""Module state Rondônia"""


def start(st_reg_number):
    """Checks the number valiaty for the Rondônia state"""

    divisor = 11

    weight = [6, 5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2]

    if len(st_reg_number) != 9 and len(st_reg_number) != 14:
        return False

    if len(st_reg_number) == 9:
        sum_total = 0
        peso = 6
        for i in range(3, len(st_reg_number)-1):
            sum_total = sum_total + int(st_reg_number[i]) * peso
            peso = peso - 1

        rest_division = sum_total % divisor
        digit = divisor - rest_division

        if digit == 10:
            digit = 0

        if digit == 11:
            digit = 1

        return digit == int(st_reg_number[len(st_reg_number)-1])

    else:
        sum_total = 0
        for i in range(len(st_reg_number)-1):
            sum_total = sum_total + int(st_reg_number[i]) * weight[i]

        rest_division = sum_total % divisor
        digit = divisor - rest_division

        if digit == 10:
            digit = 0

        if digit == 11:
            digit = 1

        return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*
"""Module states Minas Gerais"""


def start(st_reg_number):
    """Checks the number valiaty for the Minas Gerais state"""
    #st_reg_number = str(st_reg_number)
    number_state_registration_first_digit = st_reg_number[0:3] + '0' + st_reg_number[3: len(st_reg_number)-2]
    weights_first_digit = [1, 2, 1, 2, 1, 2, 1, 2, 1, 2, 1, 2]
    wights_second_digit = [3, 2, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2]
    first_digit = st_reg_number[-2]
    second_digit = st_reg_number[-1]
    sum_first_digit = 0
    sum_second_digit = 0
    sum_result_digit = ''
    sum_end = 0

    if len(st_reg_number) != 13:

        return False

    for i in range(0, 12):

        sum_first_digit = weights_first_digit[i] * int(number_state_registration_first_digit[i])

        sum_result_digit = sum_result_digit + str(sum_first_digit)

    for i in range(0, len(sum_result_digit)):

        sum_end = sum_end + int(sum_result_digit[i])

    if sum_end % 10 == 0:

        check_digit_one = 0

    elif sum_end < 10:

        check_digit_one = 10 - sum_end

    elif sum_end > 10:

        check_digit_one = (10 - sum_end % 10)

    if str(check_digit_one) != first_digit:

        return False

    number_state_registration_second_digit = st_reg_number + str(check_digit_one)

    for i in range(0, 12):

        sum_second_digit = sum_second_digit + wights_second_digit[i] * int(number_state_registration_second_digit[i])

    check_second_digit = 11 - sum_second_digit % 11

    if sum_second_digit == 1 or sum_second_digit == 0:

        return second_digit == '0'

    else:
        return str(check_second_digit) == second_digit



# *-* coding:utf-8 *-*
"""Module states Pernanbuco"""


def start(st_reg_number):
    """Checks the number valiaty for the Pernanbuco state"""
    divisor = 11

    if len(st_reg_number) > 9:
        return False

    if len(st_reg_number) < 9:
        return False

    sum_total = 0
    peso = 8
    for i in range(len(st_reg_number)-2):
        sum_total = sum_total + int(st_reg_number[i]) * peso
        peso = peso - 1

        rest_division = sum_total % divisor
        digit_first = divisor - rest_division

    if rest_division < 2:
        digit_first = 0

    if rest_division > 1:
        digit_first = 11 - rest_division

    num = 0
    peso = 9
    mult = 10000000
    for i in range(len(st_reg_number)-2):
        num = num + int(st_reg_number[i]) * mult
        mult = mult // 10

    num = num + digit_first

    new_st = str(num)
    sum_total = 0
    peso = 9
    for i in range(len(new_st)-1):
        sum_total = sum_total + int(new_st[i]) * peso
        peso = peso - 1

    rest_division = sum_total % divisor

    if rest_division < 2:
        digit_secund = 0

    if rest_division > 1:
        digit_secund = divisor - rest_division

    if digit_secund == int(st_reg_number[len(st_reg_number)-1]) and digit_first == int(st_reg_number[len(st_reg_number)-2]):
        return True
    else:
        return False



# *-* coding:utf-8 *-*
"""Module states Amapa"""


def start(st_reg_number):
    """Checks the number valiaty for the Alagoas state"""

    divisor = 11
    if len(st_reg_number) > 9:
        return False

    if len(st_reg_number) < 9:
        return False

    if st_reg_number[0:2] != "03":
        return False

    aux = int(st_reg_number[0:len(st_reg_number) - 1])

    if 3000000 < aux and aux < 3017001:
        control1 = 5
        control2 = 0

    if 3017000 < aux and aux < 3019023:
        control1 = 9
        control2 = 1

    if aux > 3019022:
        control1 = 0
        control2 = 0
    sum_total = 0
    peso = 9
    for i in range(len(st_reg_number)-1):
        sum_total = sum_total + int(st_reg_number[i]) * peso
        peso = peso - 1
    sum_total += control1

    rest_division = sum_total % divisor
    digit = divisor - rest_division

    if digit == 10:
        digit = 0

    if digit == 11:
        digit = control2

    return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*
"""Amazonas state module"""


def start(st_reg_number):
        """Checks the number valiaty for the Amazonas state"""
        weights = range(2, 10)
        digits = st_reg_number[0:len(st_reg_number) - 1]
        control_digit = 11
        check_digit = st_reg_number[-1:]

        if len(st_reg_number) != 9:
                return False

        sum_total = 0

        for i in weights:
                sum_total = sum_total + i * int(digits[i-2])

        if sum_total < control_digit:
                control_digit = 11 - sum_total
                return str(digit_calculated) == check_digit

        elif sum_total % 11 <= 1:
                return '0' == check_digit

        else:
                digit_calculated = 11 - sum_total % 11
                return str(digit_calculated) == check_digit



# *-* coding:utf-8 *-*
"""Module states Bahia"""


def start(st_reg_number):
    """Checks the number valiaty for the Bahia state"""

    weights_second_digit = range(len(st_reg_number)-1, 1, -1)
    weights_first_digit = range(len(st_reg_number), 1, -1)
    second_digits = st_reg_number[-1:]
    number_state_registration = st_reg_number[0:len(st_reg_number) - 2]
    digits_state_registration = st_reg_number[-2:]
    sum_second_digit = 0
    sum_first_digit = 0

    if len(st_reg_number) != 8 and len(st_reg_number) != 9:
        return False

    if st_reg_number[-8] in ['0', '1', '2', '3', '4', '5', '8']:

        for i in weights_second_digit:

            sum_second_digit = sum_second_digit + i*int(st_reg_number[-i-1])

        second_digits_check = 10 - (sum_second_digit % 10)

        if sum_second_digit % 10 == 0 or sum_second_digit % 11 == 1:

            second_digits_check = '0'

        if str(second_digits_check) != second_digits:

            return False

        digit_two = number_state_registration + str(second_digits_check)

        for i in weights_first_digit:

            sum_first_digit = sum_first_digit + i*int(digit_two[-i+1])

        first_digits_check = 10 - (sum_first_digit % 10)

        if sum_first_digit % 10 == 0 or sum_first_digit % 10 == 1:
            first_digits_check = '0'

        digits_calculated = str(first_digits_check) + str(second_digits_check)

        return digits_calculated == digits_state_registration

    elif st_reg_number[-8] in ['6', '7', '9']:

        for i in weights_second_digit:

            sum_second_digit = sum_second_digit + i*int(st_reg_number[-i-1])

        second_digits_check = 11 - (sum_second_digit % 11)

        if sum_second_digit % 11 == 0 or sum_second_digit % 11 == 1:
            second_digits_check = '0'

        if str(second_digits_check) != second_digits:
            return False

        digit_two = number_state_registration + str(second_digits_check)

        for i in weights_first_digit:

            sum_first_digit = sum_first_digit + i*int(digit_two[-i+1])

        first_digits_check = 11 - (sum_first_digit % 11)

        if sum_first_digit % 11 == 0 or sum_first_digit % 11 == 1:
            first_digits_check = '0'
        digits_calculated = str(first_digits_check) + str(second_digits_check)
        return digits_calculated == digits_state_registration



# *-* coding:utf-8 *-*
"""Module states Alagoas"""


def start(st_reg_number):
    """Checks the number valiaty for the Alagoas state"""

    if len(st_reg_number) > 9:
        return False

    if len(st_reg_number) < 9:
        return False

    if st_reg_number[0:2] != "24":
        return False

    if st_reg_number[2] not in ['0', '3', '5', '7', '8']:
        return False

    aux = 9
    sum_total = 0
    for i in range(len(st_reg_number)-1):
        sum_total = sum_total + int(st_reg_number[i]) * aux
        aux -= 1

    product = sum_total * 10

    aux_2 = int(product/11)

    digit = product - aux_2 * 11

    if digit == 10:
        digit = 0

    return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*
"""Module state Roraima"""


def start(st_reg_number):
    """Checks the number valiaty for the Roraima state"""

    divisor = 9

    if len(st_reg_number) > 9:
        return False

    if len(st_reg_number) < 9:
        return False

    if st_reg_number[0:2] != "24":
        return False

    sum_total = 0
    peso = 1
    for i in range(len(st_reg_number)-1):
        sum_total = sum_total + int(st_reg_number[i]) * peso
        peso = peso + 1

    digit = sum_total % divisor

    return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*
"""Module state Tocantins"""


def start(st_reg_number):
    """Checks the number valiaty for the Tocantins state"""
    divisor = 11

    if len(st_reg_number) > 11:
        return False

    if len(st_reg_number) < 11:
        return False

    if st_reg_number[2:4] not in ['01', '02', '03', '99']:
        return False

    sum_total = 0
    peso = 9
    for i in range(len(st_reg_number)-1):
        if i != 2 and i != 3:
            sum_total = sum_total + int(st_reg_number[i]) * peso
            peso = peso - 1

    rest_division = sum_total % divisor
    digit = divisor - rest_division

    if rest_division < 2:
        digit = 0

    return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*
"""Module state Rio de Janeiro"""


def start(st_reg_number):
    """Checks the number valiaty for the Rio de Janeiro state"""
    divisor = 11

    weights = [2, 7, 6, 5, 4, 3, 2]

    if len(st_reg_number) > 8:
        return False

    if len(st_reg_number) < 8:
        return False

    sum_total = 0
    for i in range(len(st_reg_number)-1):
        sum_total = sum_total + int(st_reg_number[i]) * weights[i]

    rest_division = sum_total % divisor
    digit = divisor - rest_division

    if rest_division < 2:
        digit = 0

    return digit == int(st_reg_number[len(st_reg_number)-1])



# -*- coding: utf-8 -*-
"""Module de validation the states number"""

import os
import sys
sys.path.append(os.path.abspath(os.path.dirname(__file__) + '/' + '../..'))

from ie import (  # noqa
    ac,
    al,
    am,
    ap,
    ba,
    ce,
    df,
    es,
    go,
    ma,
    mt,
    ms,
    mg,
    pa,
    pb,
    pe,
    pi,
    pr,
    rj,
    rn,
    rs,
    ro,
    rr,
    sc,
    sp,
    se,
    to
)


def start(state_registration_number, state_abbreviation):
    """
        This function is like a Facade to another modules that
        makes their own state validation.

        state_registration_number - string brazilian state registration number
        state_abbreviation  - state abbreviation

        AC (Acre)
        AL (Alagoas)
        AM (Amazonas)
        AP (Amapá)
        BA (Bahia)
        CE (Ceará)
        DF (Distrito Federal)
        ES (Espírito Santo')
        GO (Goias)
        MA (Maranhão)
        MG (Minas Gerais)
        MS (Mato Grosso do Sul)
        MT (Mato Grosso)
        PA (Pará)
        PB (Paraíba)
        PE (Pernambuco)
        PI (Piauí)
        PR (Paraná)
        RJ (Rio de Janeiro)
        RN (Rio Grande do Norte)
        RO (Rondônia)
        RR (Roraima)
        RS (Rio Grande do Sul)
        SC (Santa Catarina)
        SE (Sergipe)
        SP (São Paulo)
        TO (Tocantins)
    """

    state_abbreviation = state_abbreviation.upper()
    states_validations = {
        'AC': "ac.start(" + "\"" + state_registration_number + "\"" + ")",
        'AL': "al.start(" + "\"" + state_registration_number + "\"" + ")",
        'AM': "am.start(" + "\"" + state_registration_number + "\"" + ")",
        'AP': "ap.start(" + "\"" + state_registration_number + "\"" + ")",
        'BA': "ba.start(" + "\"" + state_registration_number + "\"" + ")",
        'CE': "ce.start(" + "\"" + state_registration_number + "\"" + ")",
        'DF': "df.start(" + "\"" + state_registration_number + "\"" + ")",
        'ES': "es.start(" + "\"" + state_registration_number + "\"" + ")",
        'GO': "go.start(" + "\"" + state_registration_number + "\"" + ")",
        'MA': "ma.start(" + "\"" + state_registration_number + "\"" + ")",
        'MG': "mg.start(" + "\"" + state_registration_number + "\"" + ")",
        'MS': "ms.start(" + "\"" + state_registration_number + "\"" + ")",
        'MT': "mt.start(" + "\"" + state_registration_number + "\"" + ")",
        'PA': "pa.start(" + "\"" + state_registration_number + "\"" + ")",
        'PB': "pb.start(" + "\"" + state_registration_number + "\"" + ")",
        'PE': "pe.start(" + "\"" + state_registration_number + "\"" + ")",
        'PI': "pi.start(" + "\"" + state_registration_number + "\"" + ")",
        'PR': "pr.start(" + "\"" + state_registration_number + "\"" + ")",
        'RJ': "rj.start(" + "\"" + state_registration_number + "\"" + ")",
        'RN': "rn.start(" + "\"" + state_registration_number + "\"" + ")",
        'RO': "ro.start(" + "\"" + state_registration_number + "\"" + ")",
        'RR': "rr.start(" + "\"" + state_registration_number + "\"" + ")",
        'RS': "rs.start(" + "\"" + state_registration_number + "\"" + ")",
        'SC': "sc.start(" + "\"" + state_registration_number + "\"" + ")",
        'SE': "se.start(" + "\"" + state_registration_number + "\"" + ")",
        'SP': "sp.start(" + "\"" + state_registration_number + "\"" + ")",
        'TO': "to.start(" + "\"" + state_registration_number + "\"" + ")"

    }

    return eval(states_validations[state_abbreviation])



# *-* coding:utf-8 *-*
"""Module state Rio Grande do Sul"""


def start(st_reg_number):
    """Checks the number valiaty for the Rio Grande do Sul state"""

    divisor = 11

    weights = [2, 9, 8, 7, 6, 5, 4, 3, 2]

    if len(st_reg_number) > 10:
        return False

    if len(st_reg_number) < 10:
        return False

    sum_total = 0
    for i in range(len(st_reg_number)-1):
        sum_total = sum_total + int(st_reg_number[i]) * weights[i]

    rest_division = sum_total % divisor
    digit = divisor - rest_division

    if digit == 10 or digit == 11:
        digit = 0

    return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*
"""Module state Rio Grande do Norte"""


def start(st_reg_number):
    """Checks the number valiaty for the Rio Grande do Norte state"""

    divisor = 11

    if len(st_reg_number) > 10:
        return False

    if len(st_reg_number) < 9:
        return False

    if st_reg_number[0:2] != "20":
        return False

    sum_total = 0
    peso = len(st_reg_number)
    for i in range(len(st_reg_number)-1):
        sum_total = sum_total + int(st_reg_number[i]) * peso
        peso = peso - 1

    mult = sum_total * 10
    digit = mult % divisor

    if digit == 10:
        digit = 0

    return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*
"""Module states Ceara"""


def algoritm_df(st_reg_number):
    """Checks the number valiaty for the Distrito Federal state"""
    st_reg_number = str(st_reg_number)
    weights = [4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2]
    digits = st_reg_number[:len(st_reg_number) - 2]
    check_digits = st_reg_number[-2:]
    divisor = 11

    sum_total = 0
    for i in range(len(digits)):
        sum_total = sum_total + int(digits[i]) * weights[i]

    rest_division = sum_total % divisor
    first_digit = divisor - rest_division

    if first_digit == 10 or first_digit == 11:
        first_digit = 0

    if str(first_digit) != check_digits[0]:

        return False

    digits = digits + str(first_digit)
    weights = [5] + weights

    sum_total = 0
    for i in range(len(digits)):
        sum_total = sum_total + int(digits[i]) * weights[i]

    rest_division = sum_total % divisor
    second_digit = divisor - rest_division

    if second_digit == 10 or second_digit == 11:
        second_digit = 0

    return str(first_digit) + str(second_digit) == check_digits


def start(st_reg_number):
    """Checks the number valiaty for the Distrito Federal state"""

    if st_reg_number[0:2] != '07':

        return False

    if len(st_reg_number) != 13:

        return False

    return algoritm_df(st_reg_number)



# *-* coding:utf-8 *-*
"""Module states Goais"""


def start(st_reg_number):
    """Checks the number valiaty for the Espirito Santo state"""

    weights = [9, 8, 7, 6, 5, 4, 3, 2]
    number_state_registration = st_reg_number[0:len(st_reg_number) - 1]
    digit_state_registration = st_reg_number[-1]

    if st_reg_number[0:2] not in ['10', '11', '12']:
        return False

    if len(st_reg_number) != 9:
        return False

    sum_total = 0

    for i in weights:
        sum_total = sum_total + i * (int(number_state_registration[-i+1]))

    check_number = int(number_state_registration) <= 10119997

    if sum_total % 11 == 0:
        return '0' == digit_state_registration

    elif sum_total % 11 == 1 and (int(number_state_registration) >= 10103105 and check_number):
        return '1' == digit_state_registration

    elif sum_total % 11 == 1:
        return '0' == digit_state_registration

    else:
        digit_check = 11 - sum_total % 11
        return digit_state_registration == str(digit_check)

    if number_state_registration == '11094402' and (number_state_registration == '1' or number_state_registration == '0'):
        return True



# *-* coding:utf-8 *-*
"""Module states Mato Grosso do Sul"""


def start(st_reg_number):
    """Checks the number valiaty for the Mato Grosso do Sul state"""

    divisor = 11

    if len(st_reg_number) > 9:
        return False

    if len(st_reg_number) < 9:
        return False

    if st_reg_number[0:2] != "28":
        return False

    sum_total = 0
    peso = 9
    for i in range(len(st_reg_number)-1):
        sum_total = sum_total + int(st_reg_number[i]) * peso
        peso = peso - 1

    rest_division = sum_total % divisor

    if rest_division == 0:
        digit = 0

    else:
        digit = divisor - rest_division
        if digit > 9:
            digit = 0

    return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*

from setuptools import setup

setup(name='ie',
      version='2.0.0',
      description='Validation of brazilian state registration numbers',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.7',
          'Topic :: Software Development :: Libraries :: Python Modules',
      ],
      keywords='inscrição estadual inscricao estadual inscricoes estaduais inscrições estaduais validacao validação',
      url='https://github.com/matheuscas/pyIE',
      author='Matheus Cardoso',
      author_email='matheus.mcas@gmail.com',
      license='MIT',
      packages=['ie'],
          tests_require=['tox'],
      zip_safe=False)


# *-* coding:utf-8 *-*
"""Module states Parana"""


def start(st_reg_number):
    """Checks the number valiaty for the Parana state"""
    divisor = 11
    weights_first = [3, 2, 7, 6, 5, 4, 3, 2]
    weights_secund = [4, 3, 2, 7, 6, 5, 4, 3, 2]

    if len(st_reg_number) > 10:
        return False

    if len(st_reg_number) < 10:
        return False

    sum_total = 0
    for i in range(len(st_reg_number)-2):
        sum_total = sum_total + int(st_reg_number[i]) * weights_first[i]

        rest_division = sum_total % divisor
    digit_first = divisor - rest_division

    if digit_first == 10 or digit_first == 11:
        digit_first = 0

    num = 0
    mult = 100000000
    for i in range(len(st_reg_number)-2):
        num = num + int(st_reg_number[i]) * mult
        mult = mult // 10

    num = num + digit_first

    if num < 10000000:
        new_st = str('0') + str(num)
    else:
        new_st = str(num)

    sum_total = 0
    for i in range(len(new_st)):
        sum_total = sum_total + int(new_st[i]) * weights_secund[i]

    rest_division = sum_total % divisor
    digit_secund = divisor - rest_division

    if digit_secund == 10 or digit_secund == 11:
        digit_secund = 0

    digit_first_check = digit_first == int(st_reg_number[len(st_reg_number)-2])

    if digit_secund == int(st_reg_number[len(st_reg_number)-1]) and digit_first_check:
        return True
    else:
        return False



# *-* coding:utf-8 *-*
"""Module state São Paulo"""


def start(st_reg_number):
    """Checks the number valiaty for the São Paulo state"""
    divisor = 11

    verificador_one = int(st_reg_number[len(st_reg_number)-4])
    verificador_two = int(st_reg_number[len(st_reg_number)-1])
    weights_first = [1, 3, 4, 5, 6, 7, 8, 10]
    weights_secund = [3, 2, 10, 9, 8, 7, 6, 5, 4, 3, 2]

    if len(st_reg_number) > 13:
        return False

    if len(st_reg_number) < 12:
        return False

    if len(st_reg_number) == 12:
        sum_total = 0
        for i in range(len(st_reg_number)-4):
            sum_total = sum_total + int(st_reg_number[i]) * weights_first[i]

        rest_division = sum_total % divisor
        digit_first = rest_division

        if rest_division == 10:
            digit_first = 0

        num = 0
        mult = 10000000000

        for i in range(len(st_reg_number)-1):
            if i == 8:
                num = num + digit_first * mult
            else:
                num = num + int(st_reg_number[i]) * mult
            mult = mult // 10

        if num < 10000000000:
            new_st = str('0') + str(num)
        else:
            new_st = str(num)

        sum_total = 0
        for i in range(len(new_st)):
            sum_total = sum_total + int(new_st[i]) * weights_secund[i]

        rest_division = sum_total % divisor
        digit_secund = rest_division

        if rest_division == 10:
            digit_secund = 0

        if digit_secund == verificador_two and digit_first == verificador_one:
            return True
        else:
            return False

    else:
        if st_reg_number[0] != "P":
            return False

        sum_total = 0
        for i in range(1, 9):
            sum_total = sum_total + int(st_reg_number[i]) * weights_first[i-1]

        digit = sum_total % divisor

        if digit == 10:
            digit = 0

        return digit == int(st_reg_number[len(st_reg_number)-4])



# *-* coding:utf-8 *-*
"""Module states Espirito Santo"""


def start(st_reg_number):
    """Checks the number valiaty for the Espirito Santo state"""
    divisor = 11

    if len(st_reg_number) > 9:
        return False

    if len(st_reg_number) < 9:
        return False

    sum_total = 0
    peso = 9
    for i in range(len(st_reg_number)-1):
        sum_total = sum_total + int(st_reg_number[i]) * peso
        peso = peso - 1

    rest_division = sum_total % divisor

    if rest_division < 2:
        digit = 0

    if rest_division > 1:
        digit = 11 - rest_division

    return digit == int(st_reg_number[len(st_reg_number)-1])



# *-* coding:utf-8 *-*
"""Module states Mato Grosso"""


def start(st_reg_number):
    """Checks the number valiaty for the Mato Grosso state"""
    #st_reg_number = str(st_reg_number)
    weights = [3, 2, 9, 8, 7, 6, 5, 4, 3, 2]
    digit_state_registration = st_reg_number[-1]

    if len(st_reg_number) != 11:
        return False

    sum = 0

    for i in range(0, 10):
        sum = sum + weights[i] * int(st_reg_number[i])

    if sum % 11 == 0:
        return digit_state_registration[-1] == '0'

    digit_check = 11 - sum % 11

    return str(digit_check) == digit_state_registration
